==> trafficserver_3.0.2.orig.tar.bz2: trafficserver-3.0.2/lib/ts/Resource.cc <==
/** @file

  A brief file description

  @section license License

  Licensed to the Apache Software Foundation (ASF) under one
  or more contributor license agreements.  See the NOTICE file
  distributed with this work for additional information
  regarding copyright ownership.  The ASF licenses this file
  to you under the Apache License, Version 2.0 (the
  "License"); you may not use this file except in compliance
  with the License.  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */

#include <stdio.h>
#include <string.h>

#include "ink_port.h"
#include "Resource.h"



#if defined(TRACK_MEMORY)

/*-------------------------------------------------------------------------
  -------------------------------------------------------------------------*/
void *operator
new(size_t size)
{
  return xmalloc((unsigned int) size);
}

/*-------------------------------------------------------------------------
  -------------------------------------------------------------------------*/

void operator
delete(void *p)
{
  _xfree(p);
}

/*-------------------------------------------------------------------------
  -------------------------------------------------------------------------*/
void *operator  new[] (size_t size)
{
  return xmalloc((unsigned int) size);
}

/*-------------------------------------------------------------------------
  -------------------------------------------------------------------------*/

void operator  delete[] (void *p)
{
  _xfree(p);
}

#endif /* TRACK_MEMORY */

==> trafficserver_3.2.4.orig.tar.bz2: trafficserver-3.2.4/lib/ts/Resource.cc <==
/** @file

  A brief file description

  @section license License

  Licensed to the Apache Software Foundation (ASF) under one
  or more contributor license agreements.  See the NOTICE file
  distributed with this work for additional information
  regarding copyright ownership.  The ASF licenses this file
  to you under the Apache License, Version 2.0 (the
  "License"); you may not use this file except in compliance
  with the License.  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */

#include <stdio.h>
#include <string.h>

#include "ink_port.h"
#include "Resource.h"



#if defined(TRACK_MEMORY)

/*-------------------------------------------------------------------------
  -------------------------------------------------------------------------*/
void *
operator new(size_t size)
{
  return ats_malloc((unsigned int) size);
}

/*-------------------------------------------------------------------------
  -------------------------------------------------------------------------*/

void operator
delete(void *p)
{
  ats_free(p);
}

/*-------------------------------------------------------------------------
  -------------------------------------------------------------------------*/
void *
operator  new[] (size_t size)
{
  return ats_malloc((unsigned int) size);
}

/*-------------------------------------------------------------------------
  -------------------------------------------------------------------------*/

void
operator  delete[] (void *p)
{
  ats_free(p);
}

#endif /* TRACK_MEMORY */
